#
# spec file for package libsocialweb
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libsocialweb
Version:        0.25.21
Release:        lp150.3.1
Summary:        A personal social data server
License:        LGPL-2.1-only
Group:          System/Libraries
URL:            http://git.gnome.org/browse/libsocialweb/
Source0:        http://download.gnome.org/sources/libsocialweb/0.25/%{name}-%{version}.tar.xz
Source1:        README.branding
# PATCH-FIX-UPSTREAM libsocialweb-annotations.patch dimstar@opensuse.org -- Fix namespacing of introspection annotations, taken from upstream git.
Patch0:         libsocialweb-annotations.patch
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  translation-update-upstream
BuildRequires:  vala
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gconf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(rest-extras-0.7)
Requires:       %{name}-branding = %{version}
Recommends:     %{name}-lang

%description
Libsocialweb is a personal social data server, that can interact with
social web services, like Flickr, Last.fm, Twitter and Vimeo.

%package branding-upstream
Summary:        A personal social data server -- API keys from upstream
Group:          System/Libraries
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:branding-upstream)
Conflicts:      %{name}-branding
Provides:       %{name}-branding = %{version}
BuildArch:      noarch
#BRAND: Branding packages should install API keys in
#BRAND: /usr/share/libsocialweb/keys. See README.branding for more
#BRAND: details.

%description branding-upstream
Libsocialweb is a personal social data server, that can interact with
social web services, like Flickr, Last.fm, Twitter and Vimeo.

This package provides API keys from upstream, for the web services
accessible with libsocialweb.

%package -n libsocialweb0
Summary:        A personal social data server -- Library for Services
Group:          Development/Libraries/GNOME

%description -n libsocialweb0
Libsocialweb is a personal social data server, that can interact with
social web services, like Flickr, Last.fm, Twitter and Vimeo.

This package contains libraries used by libsocialweb services.

%package -n libsocialweb-client2
Summary:        A personal social data server -- Client Library
# Clients do need the server to do something useful
Group:          Development/Libraries/GNOME
Recommends:     %{name}

%description -n libsocialweb-client2
Libsocialweb is a personal social data server, that can interact with
social web services, like Flickr, Last.fm, Twitter and Vimeo.

This package contains libraries used by clients willing to use
libsocialweb features.

%package -n typelib-1_0-SocialWebClient-0_25
Summary:        A personal social data server -- Client Library, Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-SocialWebClient-0_25
Libsocialweb is a personal social data server, that can interact with
social web services, like Flickr, Last.fm, Twitter and Vimeo.

This package provides the GObject Introspection bindings for the
client library.

%package devel
Summary:        A personal social data server -- Development Files
Group:          Development/Libraries/GNOME
Requires:       libsocialweb-client2 = %{version}
Requires:       libsocialweb0 = %{version}
Requires:       typelib-1_0-SocialWebClient-0_25 = %{version}

%description devel
Libsocialweb is a personal social data server, that can interact with
social web services, like Flickr, Last.fm, Twitter and Vimeo.

%lang_package

%prep
%setup -q
translation-update-upstream
%patch0 -p1
cp %{SOURCE1} .

%build
%configure --disable-static \
    --with-gnome \
    --with-online=always \
    --enable-all-services \
    --enable-vala-bindings
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# Create directory where API keys will be stored
mkdir %{buildroot}%{_datadir}/libsocialweb/keys
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}/gtk-doc

%post -n libsocialweb0 -p /sbin/ldconfig
%postun -n libsocialweb0 -p /sbin/ldconfig
%post -n libsocialweb-client2 -p /sbin/ldconfig
%postun -n libsocialweb-client2 -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS README
# dbus core service
%{_libexecdir}/libsocialweb-core
%{_datadir}/dbus-1/services/libsocialweb.service
%dir %{_libdir}/libsocialweb
%dir %{_libdir}/libsocialweb/services
%dir %{_datadir}/libsocialweb
%dir %{_datadir}/libsocialweb/keys
%dir %{_datadir}/libsocialweb/services
# plugins for various web services
# Explicitly list services to make sure we don't lose any
%{_libdir}/libsocialweb/services/libfacebook.so
%{_datadir}/libsocialweb/services/facebook.keys
%{_libdir}/libsocialweb/services/libflickr.so
%{_datadir}/libsocialweb/services/flickr.keys
%{_libdir}/libsocialweb/services/liblastfm.so
%{_datadir}/libsocialweb/services/lastfm.keys
%{_datadir}/libsocialweb/services/lastfm.png
%{_libdir}/libsocialweb/services/libmyspace.so
%{_datadir}/libsocialweb/services/myspace.keys
%{_datadir}/libsocialweb/services/myspace.png
%{_libdir}/libsocialweb/services/libphotobucket.so
%{_datadir}/libsocialweb/services/photobucket.keys
%{_libdir}/libsocialweb/services/libplurk.so
%{_datadir}/libsocialweb/services/plurk.keys
%{_datadir}/libsocialweb/services/plurk.png
%{_libdir}/libsocialweb/services/libsina.so
%{_datadir}/libsocialweb/services/sina.keys
%{_datadir}/libsocialweb/services/sina.png
%{_libdir}/libsocialweb/services/libsmugmug.so
%{_datadir}/libsocialweb/services/smugmug.keys
%{_libdir}/libsocialweb/services/libtwitter.so
%{_datadir}/libsocialweb/services/twitter.keys
%{_datadir}/libsocialweb/services/twitter.png
%{_libdir}/libsocialweb/services/libvimeo.so
%{_datadir}/libsocialweb/services/vimeo.keys
%{_datadir}/libsocialweb/services/vimeo.png
%{_libdir}/libsocialweb/services/libyoutube.so
%{_datadir}/libsocialweb/services/youtube.keys
%{_datadir}/libsocialweb/services/youtube.png

%files branding-upstream
%doc README.branding

%files -n libsocialweb0
%{_libdir}/libsocialweb.so.*
%{_libdir}/libsocialweb-keyfob.so.*
%{_libdir}/libsocialweb-keystore.so.*

%files -n libsocialweb-client2
%{_libdir}/libsocialweb-client.so.*

%files -n typelib-1_0-SocialWebClient-0_25
%{_libdir}/girepository-1.0/SocialWebClient-0.25.typelib

%files devel
%{_libdir}/*.so
%{_includedir}/libsocialweb/
%{_libdir}/pkgconfig/libsocialweb-client.pc
%{_libdir}/pkgconfig/libsocialweb-keyfob.pc
%{_libdir}/pkgconfig/libsocialweb-keystore.pc
%{_libdir}/pkgconfig/libsocialweb-module.pc
%{_datadir}/gir-1.0/SocialWebClient-0.25.gir
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/*.deps
%{_datadir}/vala/vapi/*.vapi
%doc %{_datadir}/gtk-doc/html/libsocialweb/
%doc %{_datadir}/gtk-doc/html/libsocialweb-dbus/
%doc %{_datadir}/gtk-doc/html/libsocialweb-client/

%files lang -f %{name}.lang

%changelog
* Sun Apr 15 2018 bjorn.lie@gmail.com
- Drop pkgconfig(libnm-glib) BuildRequires, as it is deprecated
  upstream and going away soon.
- Following the above, pass --with-online=always in place of the
  previous --with-online=networkmanager to configure.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Feb 28 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Mon Oct 15 2012 dimstar@opensuse.org
- Update to version 0.25.21:
  + flickr: Only try and check the token if we have one.
* Mon Jul 30 2012 dimstar@opensuse.org
- Add libsocialweb-annotations.patch: Fix gobject-introspection
  annotations.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-SocialWebClient-0_25
  subpackage.
- Add typelib-1_0-SocialWebClient-0_25 Requires to devel
  subpackage.
* Sat Nov 12 2011 dimstar@opensuse.org
- Update to version 0.25.20:
  + login to last.fm to validate credentials [MeeGo#8986]
  + only try and fetch content if credentials are valid.
  + Minor bug fixes.
* Wed Jul  6 2011 vuntz@opensuse.org
- Create a branding-upstream subpackage, with a README.branding
  file explaining how to add API keys.
- Add a libsocialweb-branding Requires to the main package, since
  API keys are provided in branding packages, and they make
  libsocialweb more useful.
- Create %%{_datadir}/libsocialweb/keys and have the main package
  own it.
* Mon Jul  4 2011 vuntz@opensuse.org
- Update to version 0.25.19:
  + vimeo:
  - Added collections interface.
  - Change auth details to get write permissions.
  - Disable cookies on REST proxy to avoid bug on Vimeo's side.
  - Add video upload support.
* Fri Jun 10 2011 dimstar@opensuse.org
- Update to version 0.25.18:
  + MeeGo#17763: Register the contact view on a unique D-Bus path.
  + MeeGo#17863: Don't use G_N_ELEMENTS on non-local arrays.
* Fri May 27 2011 vuntz@opensuse.org
- Build vala bindings: add vala BuildRequires and pass
  - -enable-vala-bindings to configure.
* Wed May 18 2011 dimstar@opensuse.org
- Update to version 0.25.17:
  + facebook/lastfm: Use larger avatar picture.
  + myspace: Fix potential corruption bug.
  + youtube: Correct capitalization of YouTube Name.
  + Code cleanups and build fixes.
  + Updated translations.
* Thu Apr 28 2011 fcrozat@novell.com
- Update to version 0.25.16:
  + Add MySpace service
  + flickr: Support upload progress.
  + facebook: Support upload progress.
  + photobucket: Support upload progress.
  + smugmug: Support upload progress.
  + twitter: Support upload progress.
  + youtube: Support upload progress.
  + keystore: Implementation of requesting API keys from kernel
    keyring.
  + Fix memory leak.
  + Updated translations
* Thu Apr  7 2011 fcrozat@novell.com
- Update to version 0.25.15:
  + Contacts-related fixes.
  + Flickr: implement contacts support
  + Twitter: implement contacts support
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 0.25.14:
  + introspection: annotations for capabilities
  + Add contacts API and support in Facebook, lastfm services.
  + Facebook: various fixes.
* Wed Mar 23 2011 fcrozat@novell.com
- Update to version 0.25.13
  + Youtube: Added support for video upload
  + Photobucket: Added has-collections-iface capability.
  + Updated translations.
* Thu Mar 17 2011 fcrozat@novell.com
- Update to version 0.25.12
  + Add Plurk service.
  + Add Youtube service.
  + Add Sina service.
  + Add photobucket service.
  + Add introspection support
  + Add vala binding
  + Add support for NetworkManager 0.9.
  + Add and use sw_service_map_params for cleanly mapping lsw
    parameters.
  + Add Collections.GetCreatableTypes() to know which types can be
    created.
  + Flickr:
  - Add x-flickr-tags upload parameter.
  + SmugMug:
  - Robustify remote error handling.
  - Add support for dynamic caps.
  - Fix Collections.GetDetails.
  + Vimeo:
  - Add oauth support.
  + Updated translations.
- Add gobject-introspection-devel and libxslt BuildRequires.
* Thu Mar  3 2011 vuntz@opensuse.org
- Update to version 0.25.11:
  + Add Facebook service.
  + Add SmugMug module.
- Changes from version 0.25.10:
  + Make service errors proper dbus errors.
  + Add collections dbus interface.
- Changes from version 0.25.9:
  + Add video upload support to flickr service.
  + twitter-item-view: Unescape the content for the twitter item
    view.
  + Stop update timeouts when the credentials are invalid.
- Changes from version 0.25.8:
  + Load the service information from datadir, not from the user
    directory.
- Changes from version 0.25.7:
  + No real change.
- Pass --enable-all-services to configure to build support for all
  services.
* Thu Mar  3 2011 vuntz@opensuse.org
- Cleanup for proper inclusion in Factory:
  + General cleanup of spec file.
  + Improved summaries and descriptions.
  + Split libsocialweb0 and libsocialweb-client2 subpackages.
  + Merge the doc subpackage in devel subpackage.
  + Create lang subpackage.
* Tue Feb 15 2011 fcrozat@novell.com
- Update to version 0.25.7:
  - no code change, hosting moved to GNOME infrastructure
* Thu Jan 20 2011 awafaa@opensuse.org
- Update to version 0.25.6
* Fri Nov  5 2010 awafaa@opensuse.org
- Update to version 0.25.4
* Tue Sep  7 2010 awafaa@opensuse.org
- Spec file clean up
- Update to version 0.25.4
* Mon Jul 19 2010 awafaa@opensuse.org
- Update to version 0.24.9
* Thu Jul  8 2010 awafaa@opensuse.org
- Switch from using conman to NetworkManager
- Enable digg, Flickr, Facebook & MySpace
* Thu Jun 10 2010 awafaa@opensuse.org
- Initial import for openSUSE version 0.24.6
